---
name: Open an issue
about: Report a problem or discuss a new feature
---

<!--
Thank you for taking the time to report an issue! We're glad to have you involved with aiomqtt.

If you're filing a bug report, please consider including the following information:

- The version of aiomqtt
- A minimal self-contained code snippet that reproduces the bug (you can use `test.mosquitto.org` for a publicly available MQTT broker)
- Possibly related issues
-->
